@@ -1,5 +1,5 @@
 from arkclient import GameBotClient
-from arkdriver.lib import Ini
+from arklibrary.lib import Ini
 from arkdriver import Admin
 from pathlib import Path
 from time import sleep
